==> MongoDBx-Class-0.7.tar.gz: MongoDBx-Class-0.7/lib/MongoDBx/Class/Meta/AttributeTraits.pm <==
package MongoDBx::Class::Meta::AttributeTraits;
BEGIN {
  $MongoDBx::Class::Meta::AttributeTraits::VERSION = '0.7';
}

# ABSTRACT: Attribute traits provided by MongoDBx::Class

=head1 NAME

MongoDBx::Class::Meta::AttributeTraits - Attribute traits provided by MongoDBx::Class

=head1 VERSION

version 0.7

=cut

package MongoDBx::Class::Meta::AttributeTraits::Parsed;
BEGIN {
  $MongoDBx::Class::Meta::AttributeTraits::Parsed::VERSION = '0.7';
}

# ABSTRACT: An attribute trait for attributes automatically expanded and collapsed by a parser class.

use Moose::Role;
use namespace::autoclean;

=head1 NAME

MongoDBx::Class::Meta::AttributeTraits::Parsed - An attribute trait for attributes automatically expanded and collapsed by a parser class.

=cut

has 'parser' => (is => 'ro', isa => 'Str', lazy_build => 1);

sub _build_parser {
	'MongoDBx::Class::ParsedAttribute::'.shift->{isa};
}

{
	package Moose::Meta::Attribute::Custom::Trait::Parsed;
BEGIN {
  $Moose::Meta::Attribute::Custom::Trait::Parsed::VERSION = '0.7';
}
	sub register_implementation { 'MongoDBx::Class::Meta::AttributeTraits::Parsed' }
}

=head1 AUTHOR

Ido Perlmuter, C<< <ido at ido50.net> >>

=head1 LICENSE AND COPYRIGHT

Copyright 2010-2011 Ido Perlmuter.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

1;

==> MongoDBx-Class-1.00.tar.gz: MongoDBx-Class-1.00/lib/MongoDBx/Class/Meta/AttributeTraits.pm <==
package MongoDBx::Class::Meta::AttributeTraits;

# ABSTRACT: Attribute traits provided by MongoDBx::Class

our $VERSION = "1.00";
$VERSION = eval $VERSION;

=head1 NAME

MongoDBx::Class::Meta::AttributeTraits - Attribute traits provided by MongoDBx::Class

=head1 VERSION

version 1.00

=cut

package MongoDBx::Class::Meta::AttributeTraits::Parsed;

# ABSTRACT: An attribute trait for attributes automatically expanded and collapsed by a parser class

our $VERSION = "1.00";
$VERSION = eval $VERSION;

use Moose::Role;
use namespace::autoclean;

=head1 NAME

MongoDBx::Class::Meta::AttributeTraits::Parsed - An attribute trait for attributes automatically expanded and collapsed by a parser class.

=cut

has 'parser' => (is => 'ro', isa => 'Str', lazy_build => 1);

sub _build_parser {
	'MongoDBx::Class::ParsedAttribute::'.shift->{isa};
}

{
	package Moose::Meta::Attribute::Custom::Trait::Parsed;
	sub register_implementation { 'MongoDBx::Class::Meta::AttributeTraits::Parsed' }
}

package MongoDBx::Class::Meta::AttributeTraits::Transient;

# ABSTRACT: An attribute trait for attributes not saved in the database

our $VERSION = "1.00";
$VERSION = eval $VERSION;

use Moose::Role;
use namespace::autoclean;

{
	package Moose::Meta::Attribute::Custom::Trait::Transient;
	sub register_implementation { 'MongoDBx::Class::Meta::AttributeTraits::Transient' }
}

=head1 AUTHOR

Ido Perlmuter, C<< <ido at ido50.net> >>

=head1 LICENSE AND COPYRIGHT

Copyright 2010-2012 Ido Perlmuter.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

1;
